General Notes — polyfemos 0.3.29 documentation

# General Notes

organization

  Sodankylä Geophysical Observatory, University of Oulu

copyright

  University of Oulu, Sodankylä Geophysical Observatory

date

  2019

The polyfemos package and its documentation is distributed under GNU Lesser General Public License v3.0 or later. Exceptions are listed below.

The polyfemos package comes with `sorttable.js` table sorter by Stuart Langridge, <http://www.kryogenix.org/code/browser/sorttable/>. The source file is not modified. The `sorttable.js` is provided under licence <http://www.kryogenix.org/code/browser/licence.html>.

The ‘northern_finland.png’ example png map file is licensed as CC BY-SA <https://creativecommons.org/licenses/by-sa/2.0/>. Copyright OpenStreetMap contributors <https://www.openstreetmap.org/copyright>.

The data contained in folder ‘polyfemos_example_data’ is licenced under ‘SGO Data Licence Agreement, 8.11.2019’. The licence file ‘SGO_DATA_LICENCE_AGREEMENT.txt’ is provided with the data.

The polyfemos backend is made seismic studies in mind and currently supports only seismic instruments. For the most part, the frontend (polyfemos web) on the other hand should be compatible with anything that is capable of producing ‘*.stf’, ‘*.csv’ and ‘*.alert’ files in suitable formats. See Sohtextfile Format, Alert file Format and State of health CSV Format for more information.

## Supported Hardware

The polyfemos (back and front) currently supports following hardware.

| Brand | Model | Internal code
--- | --- | --- | ---
Sensor | Nanometrics | Trillium 120PA | `Trillium_120PA`
Nanometrics | Trillium Posthole | `Trillium_120PH`
Nanometrics | Trillium Compact 120s | `Trillium_Co120`
Streckeisen | STS-2 | `STS-2`
Digitizer | Earth Data | PS6-24 | `PS6-24`
Earth Data | EDR-210 | `EDR-210`
Nanometrics | Centaur 3 channels | `Centaur_3ch`
Nanometrics | Centaur 6 channels | `Centaur_6ch`

## Comments considering internal naming conventions

Internal name | Description
--- | ---
network_code* | Network code, e.g. “FN”
station_code* | Station code, e.g. “MSF”
location_code* | Location code, usually empty or “00”
channel_code* | Channel code, e.g. “HHZ”
station_id | Combination of network and station codes, e.g. “FN.MSF”
sohpar_name, parname | State of health parameter name, e.g. “Digitizer_input_voltage”
year | Year
julday | Day of the year

* The ‘code’ is omitted in case of the reserved variables, see Chapter Reserved variables.

Polyfemos web and polyfemos frontend will be synonymous in the documentation.

## Console scripts

Polyfemos provides next command line scripts

Script alias | Link to code
--- | ---
polyfemos-readconf | `polyfemos.back.main.readconf()`
polyfemos-devserver | `polyfemos.scripts.devserver.main()`
polyfemos-rwt | `polyfemos.scripts.render_web_templates.main()`
polyfemos-tfp | `polyfemos.scripts.test_front_paths.main()`
polyfemos-secret_key | `polyfemos.util.randomizer.get_secret_key()`
polyfemos-sohemailer | `polyfemos.scripts.sohemailer.main()`
polyfemos-check | `polyfemos.scripts.check_output_files.main()`